<?php
/*
Plugin Name: Recaptcha Mailhide
Description: Replace all email addresses with recaptchas 
Version: 1.2.3
Author: Matteo Brutti
Author email: backit.webdev@gmail.com 
Thanks to: drupal mailhide module https://www.drupal.org/project/recaptcha 
*/


/*
 *
 * read the README file in recaptcha_mailhide subdir for informations and instructions
 *
 */


# get correct id for plugin
$thisfile=basename(__FILE__, ".php");

# register plugin
register_plugin(
   $thisfile, 
   'Recaptcha Mailhide',
   '1.2.3',
   'Backit',
   '',
   'Finds email addresses in content and hides them with recaptcha, instructions in the php file',
   'recaptcha_mailhide'
);



/*
 * FUNCTIONS
 */
function recaptcha_mailhide($content){
   $content=mailto_strip($content);

   $mailPattern="/[\._a-zA-Z0-9\!\#\&\$\%\'\*\+\/\=\?\^_\`\{\|\}\(\)\~-]+@[\._a-zA-Z0-9-]+/i"; 
   preg_match_all($mailPattern, $content, $matches);
   foreach ($matches[0] as $mail){
      if ( ! preg_match('/\.\.\.@/',$mail)){

         $email = _recaptcha_replace($mail);
         $content=str_replace($mail,$email,$content);
      }
   }
   
   return $content;
}

function mailto_strip($content){
   $mailtopattern="/<a href\=\"mailto:.*?<\/a>/";
   $mailPattern="/(?<=\<a href=\"mailto:)(.*)(?=\">)/";
   $mailOnlyPattern="/(?<=\<a href=\"mailto:)(.*)(?=\?*\">)/";
   $mailOnlyPattern="/mailto:([^\?]*)/";
   $textpattern="/(?<=\>)(.*)(?=\<\/a\>)/";

   preg_match_all($mailtopattern, $content, $matches);

   foreach ($matches[0] as $mailto){ 
      preg_match($mailPattern, $mailto, $mail); /*get mail with params */
      preg_match($textpattern, $mailto, $text);
      $mail=$mail[0];
      $mailonly=$mail;
      $text=$text[0];
      if (preg_match('/\?/',$mail)){
         preg_match($mailOnlyPattern, $mailto, $mailonly); /* mail without params */
         $mailonly=$mailonly[1];
      }
      $text=str_replace($mailonly, "", $text); /* if mail == text or mail included in text => replace, else text=text */
      $email = _recaptcha_replace($mail, $text );
      $content=str_replace($mailto,$email,$content);
   }      
   return $content;
}

function recaptcha_mailhide_html_customLink($pubkey, $privkey, $email, $text=""){
   $url = recaptcha_mailhide_url($pubkey, $privkey, $email);

   if (empty($text)){
      if ( preg_match('/\?/',$email)){
         $mailOnlyPattern="/(.*)(?=\?)/"; /*email without params */
         preg_match($mailOnlyPattern,$email,$emailOnly);
         $email=$emailOnly[1];
      } 
      $emailparts = _recaptcha_mailhide_email_parts($email); 
      return  "<a href='" . htmlentities ($url) ."' onclick=\"window.open('" . htmlentities ($url) . "', '', 'toolbar=0,         scrollbars=0,location=0,statusbar=0,menubar=0,resizable=0,width=500,height=300'); return false;\" title=\"Reveal this e-mail  address\">".htmlentities($emailparts[0])."...@" . htmlentities($emailparts[1])."</a>";
   }else{
      return  "<a href='" . htmlentities ($url) ."' onclick=\"window.open('" . htmlentities ($url) . "', '', 'toolbar=0,         scrollbars=0,location=0,statusbar=0,menubar=0,resizable=0,width=500,height=300'); return false;\" title=\"Reveal this e-mail  address\">".$text."</a>";
   } 
}

function _recaptcha_replace($match, $text=""){ 
   global $_recaptcha_mailhide_public_key, $_recaptcha_mailhide_private_key;

      $match=str_replace("&amp;","&",$match); /* due to getsimple htmltoentities conversion */

      if (empty($_recaptcha_mailhide_public_key) || 
         empty($_recaptcha_mailhide_private_key) || 
         !function_exists('mcrypt_encrypt')) { 

         if (!function_exists('mcrypt_encrypt')){
            error_log('Address cannot be hidden because Mcrypt is not installed.');
         }else{
            error_log("Address cannot be hidden because the reCAPTCHA Mailhide keys are missing.");
         }

         $email = "<span id=\"mailhiderror\" style=\"color:#ff0000;\">email cannot be shown due to an error, please contact the site administrator, email in the footer.</span>";

      } else { 
         $email=recaptcha_mailhide_html_customLink($_recaptcha_mailhide_public_key,                          $_recaptcha_mailhide_private_key,$match,$text );
      }
      return $email; /* only for mailto_strip */
}


function add_debug($content){
   global $recaptcha_mailhide_debug;
   $recaptcha_mailhide_debug.="</p><hr style=\"border-color:black;\">";
   return $recaptcha_mailhide_debug.$content;
}


/*
 * MAIN
 */
$debugyes=false; /* no debug: debug=false; */
$recaptcha_mailhide_debug="";
/* to debug some variable, just add global $recaptcha_mailhide_debug; and $recaptcha_mailhide_debug.=$variable; */

if ( $debugyes ) $recaptcha_mailhide_debug="<p class=\"debug\">";


$key_file='plugins/recaptcha_mailhide/keys';
$recaptchalib='plugins/recaptcha_mailhide/recaptcha-php-1.11/recaptchalib.php';

if ( file_exists($recaptchalib)){ 
   if ( !file_exists($key_file)) $_recaptcha_mailhide_public_key = $_recaptcha_mailhide_private_key = "";
   else require_once $key_file;

   require_once $recaptchalib;
   /* pass $content variable to recaptcha_mailhide function, it must return something (content) */
   add_filter('content','recaptcha_mailhide'); 
}


if ( $debugyes ) add_filter('content','add_debug');





?>
